@@ -1,12 +1,9 @@
 author="CluBear Reserch Group"  
-version="2020-04-18 (0.0.10)" 
+version="2020-04-21 (0.0.15)" 
 
 from .dm import manager
 from .pp import pump
-from .reg import subreg
-from .sf import shuffle
-from .sub import subsample
-from .pp import check
+from .ck import check
 
 from .fun import demo
 from .fun import ady
